<?php
// Global variables define
define('RADIX_MULTIPURPOSE_PARENT_TEMPLATE_DIR_URI', get_template_directory_uri());
define('RADIX_MULTIPURPOSE_TEMPLATE_DIR_URI', get_stylesheet_directory_uri());
define('RADIX_MULTIPURPOSE_TEMPLATE_DIR', trailingslashit(get_stylesheet_directory()));

if (!function_exists('wp_body_open')) {

    function wp_body_open() {
        /**
         * Triggered after the opening <body> tag.
         */
        do_action('wp_body_open');
    }

}

// Enqueue Script
add_action('wp_enqueue_scripts', 'radix_multipurpose_enqueue_styles');

function radix_multipurpose_enqueue_styles() {
    if (get_theme_mod('custom_color_enable') == true) {
        radix_multipurpose_custom_light();
    }
    wp_enqueue_style('radix-multipurpose-parent-style', RADIX_MULTIPURPOSE_PARENT_TEMPLATE_DIR_URI . '/style.css', array('bootstrap'));
    wp_enqueue_style('radix-multipurpose-default-style', RADIX_MULTIPURPOSE_TEMPLATE_DIR_URI . '/assets/css/default.css');
    //Add Script
    wp_enqueue_script('radix-multipurpose-mp-masonry-js', RADIX_MULTIPURPOSE_TEMPLATE_DIR_URI . '/js/masonry/mp.mansory.js', array('jquery'), '', true);
}

//Setup theme
add_action('after_setup_theme', 'radix_multipurpose_setup');

function radix_multipurpose_setup() {
    load_theme_textdomain('radix-multipurpose', RADIX_MULTIPURPOSE_TEMPLATE_DIR . '/languages');

    require(RADIX_MULTIPURPOSE_TEMPLATE_DIR . '/inc/customizer/footer-options.php');
    require( RADIX_MULTIPURPOSE_TEMPLATE_DIR . '/inc/customizer/customizer_theme_style.php');

    //About Theme
    $theme = wp_get_theme(); // gets the current theme
    if ('Radix Multipurpose' == $theme->name) {
        if (is_admin()) {
            require RADIX_MULTIPURPOSE_TEMPLATE_DIR . '/admin/admin-init.php';
        }
    }
}

//Set for old user before 1.3.8
if (!get_option('honeypress_user_before_1_3_8', false)) {
    //detect old user and set value
    $radix_multipurpose_service_title=get_theme_mod('home_service_section_title');
    $radix_multipurpose_service_discription=get_theme_mod('home_service_section_discription');
    $radix_multipurpose_blog_title=get_theme_mod('home_news_section_title');
    $radix_multipurpose_blog_discription=get_theme_mod('home_news_section_discription');
    $radix_multipurpose_slider_title=get_theme_mod('home_slider_title');
    $radix_multipurpose_slider_discription=get_theme_mod('home_slider_discription');
    $radix_multipurpose_testimonial_title=get_theme_mod('home_testimonial_section_title');
    $radix_multipurpose_testimonial__discription=get_theme_mod('home_testimonial_section_discription');
    $radix_multipurpose_footer_credit=get_theme_mod('footer_copyright');

    if ($radix_multipurpose_service_title !=null || $radix_multipurpose_service_discription !=null || $radix_multipurpose_blog_title !=null || $radix_multipurpose_blog_discription !=null || $radix_multipurpose_slider_title !=null || $radix_multipurpose_slider_discription !=null || $radix_multipurpose_testimonial_title !=null || $radix_multipurpose_testimonial__discription !=null || $radix_multipurpose_footer_credit !=null )  {
        add_option('honeypress_user_before_1_3_8', 'old');

    } else {
        add_option('honeypress_user_before_1_3_8', 'new');
    }
}

// Add footer hook
add_action('radix_multipurpose_footer_section_hook', 'radix_multipurpose_footer_section_hook');

function radix_multipurpose_footer_section_hook() {
    ?>
    <footer class="site-footer">
        <div class="container">
            <?php if (is_active_sidebar('footer-sidebar-1') || is_active_sidebar('footer-sidebar-2') || is_active_sidebar('footer-sidebar-3')): ?>
                    <div class="seprator-line"></div>
            <?php
            get_template_part('sidebar', 'footer');
            endif;?>
        </div>
        <?php
        $radix_multipurpose_user=get_option('honeypress_user_before_1_3_8');
        if($radix_multipurpose_user=='old'){?>
            <div class="site-info text-center">
                <?php $radix_multipurpose_footer_copyright = get_theme_mod('footer_copyright', '<p>' . __('Proudly powered by <a href="https://wordpress.org"> WordPress</a> | Theme: <a href="https://spicethemes.com" rel="nofollow">Radix Multipurpose</a> by SpiceThemes', 'radix-multipurpose') . '</p>'); ?>
            <?php echo wp_kses_post($radix_multipurpose_footer_copyright); ?>
            </div>
        <?php } else{?>
            <div class="site-info text-center">
                 <p><?php esc_html_e( 'Proudly powered by', 'radix-multipurpose' ); ?> <a href="<?php echo esc_url( __( 'https://wordpress.org', 'radix-multipurpose' ) ); ?>"><?php esc_html_e( 'WordPress', 'radix-multipurpose' ); ?> </a> <?php esc_html_e( '| Theme:', 'radix-multipurpose' ); ?> <a href="<?php echo esc_url( __( 'https://spicethemes.com', 'radix-multipurpose' ) ); ?>" rel="nofollow"> <?php esc_html_e( 'radix-multipurpose', 'radix-multipurpose' ); ?></a> <?php esc_html_e( 'by SpiceThemes', 'radix-multipurpose' );?></p>
            </div>
        <?php } ?>
    </footer>
    <?php
}

//Add custom color function
        function radix_multipurpose_custom_light() {
            $radix_multipurpose_link_color = get_theme_mod('link_color');
            list($r, $g, $b) = sscanf($radix_multipurpose_link_color, "#%02x%02x%02x");
            $r = $r - 50;
            $g = $g - 25;
            $b = $b - 40;

            if ($radix_multipurpose_link_color != '#ff0000') :
                ?>
        <style type="text/css">
            .header-sidebar {
                background: <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            .header-logo.index6 .site-title-name:hover,.header-logo.index6 .site-title-name:focus{
                color:<?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            .services4 .post {
                background:  <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            .services4 .entry-header .entry-title a:hover{
                color:#061018!important;
            }
            #testimonial-carousel2 .testmonial-block:before {
                border-top: 25px solid <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            #testimonial-carousel2 .testmonial-block {
                border-left: 4px solid <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            .header-logo.index6 .site-title-name:hover:, .header-logo.index6 .site-title-name:focus {
                color: <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            .navbar.navbar6 ul li > a:after {
                background: <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            .services3 .post-thumbnail i.fa, .services3 .post:hover {
                background: <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            .services3 .post:hover .post-thumbnail i.fa {
                color: <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
                background: #f5f6fa!important;
            }
            .page-title-section .breadcrumb_last {
                color: <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            input[type="submit"] {
                background: <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            .navbar-nav .show .dropdown-menu > .active > a{
                color: <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            blockquote {
                border-left: 4px solid <?php echo esc_attr($radix_multipurpose_link_color); ?> !important;
            }
            body .widget .tag-cloud-link:hover, body .widget .tag-cloud-link:focus, body .site-footer .widget .tag-cloud-link:hover, body .site-footer .widget .tag-cloud-link:focus {
                background-color: <?php echo esc_attr($radix_multipurpose_link_color);?> ;
                border: 1px solid <?php echo esc_attr($radix_multipurpose_link_color);?> ;
            }
            body .site-footer .widget .tag-cloud-link:hover { color: #ffffff !important; }
        </style>
        <?php
    endif;
}

//Add Masonry Layout
add_action('wp_footer', 'radix_multipurpose_custom_script');

function radix_multipurpose_custom_script() {

    wp_reset_query();
    ?>
    <script>
        jQuery(document).ready(function (jQuery) {
            jQuery("#blog-masonry2").mpmansory(
                    {
                        childrenClass: 'item', // default is a div
                        columnClasses: 'padding', //add classes to items
                        breakpoints: {
                            xl: 4, //Change masonry column here like 2, 3, 4 column
                            lg: 4,
                            md: 6,
                            sm: 12,
                            xs: 12


                        },
                        distributeBy: {order: false, height: false, attr: 'data-order', attrOrder: 'asc'}, //default distribute by order, options => order: true/false, height: true/false, attr => 'data-order', attrOrder=> 'asc'/'desc'
                        onload: function (items) {
                            //make somthing with items
                        }
                    }
            );
        });
    </script>
    <?php
}

//Remove Footer section
function radix_multipurpose_remove_customize_register( $wp_customize ) {

   $wp_customize->remove_section( 'footer_section');

}
add_action( 'customize_register', 'radix_multipurpose_remove_customize_register',11);
